local M = {}

local bootstrap = function(path)
  if not vim.uv.fs_stat(path) then
    vim.fn.system {
      "git",
      "clone",
      "--filter=blob:none",
      "--branch=stable",
      "https://github.com/folke/lazy.nvim.git",
      path,
    }
  end
  vim.opt.rtp:prepend(path)
  return vim.F.npcall(require, "lazy")
end

local dev_path = function()
  local paths = {
    "~/Projects/nvim-plugins",
    "~/.local/src",
  }
  paths = vim.tbl_map(vim.fn.expand, paths)
  paths = vim.tbl_filter(vim.uv.fs_stat, paths)
  return paths[1]
end

M.setup = function()
  local lazy = bootstrap(vim.fn.stdpath("data") .. "/lazy/lazy.nvim")
  if not lazy then
    vim.notify("Lazy not installed and failed to bootstrap!", vim.log.levels.WARN)
    return
  end

  lazy.setup {
    spec = "fschauen.plugins",
    dev = {
      path = dev_path(),
      fallback = true,
    },
    ui = {
      border = "rounded",
      title = "  Lazy  ",
    },
    change_detection = {
      enabled = false,
    },
    performance = {
      rtp = {
        disabled_plugins = {
          "gzip",
          "matchit",
          "netrwPlugin",
          "tarPlugin",
          "tohtml",
          "tutor",
          "zipPlugin",
        },
      },
    },
  }
end

return M
