return {
  "FabijanZulj/blame.nvim",

  cmd = "BlameToggle",

  keys = {
    {
      "<leader>gb",
      "<cmd>BlameToggle<cr>",
      desc = require("fschauen.util.icons").ui.Git .. " [g]it [b]lame (blame.nvim)",
    },
  },

  opts = {
    -- Using  (0xEACC) instead of - (0x2D) in `date_format` because `blame.nvim`
    -- constructs each line and then uses `string.find({s}, {pattern})` to find
    -- the position of the date in order to set the highlight. The normal dash
    -- (0x2D) is a magic character in {pattern} and prevents the date from being
    -- found and thus the highlight fails. Escaping the dash doesn't work because
    -- the escape sequence would be visible in the final output, so my
    -- workaround is to use a symbol that _looks like_ a dash, but isn't one.
    date_format = "%Y%m%d",

    commit_detail_view = "tab", -- Open commits in a new tab.

    mappings = {
      commit_info = { "i", "K" },
    },

    -- The default format uses _committer_ time, but I want _author_ time
    -- (when I do rebases, I am interested in the original commit). A custom
    -- formatting function also allows me to slightly tweak the final output.
    format_fn = function(commit, config, idx)
      local hash = string.sub(commit.hash, 1, 7)

      if hash == "0000000" then
        return {
          idx = idx,
          values = {
            { textValue = "·······", hl = "Comment" },
            { textValue = "Not commited", hl = "Comment" },
          },
          format = "%s  %s",
        }
      end

      return {
        idx = idx,
        values = {
          { textValue = hash, hl = hash },
          { textValue = os.date(config.date_format, commit.author_time), hl = hash },
          { textValue = commit.author, hl = hash },
        },
        format = "%s  %s  %s",
      }
    end,
  },
}
